# Skytup

A sample Python package that can be installed via pip.

## Installation

You can install the package using pip:

```bash
pip install skytup
```

## Usage

```python
import skytup
```

## License

This project is licensed under the MIT License - see the LICENSE file for details.